local lib = LibStub("LibAuraInfo-1.0");
if(not lib) then error("API.lua for LibAuraInfo needs library loaded."); return; end

local debugPrint = lib.debugPrint
local strsplit = strsplit
local tonumber = tonumber
local UnitName = UnitName
local unpack = unpack
local GetTime = GetTime

local function GUIDIsPlayer(guid)
	local B = tonumber(guid:sub(5,5), 16);
	local maskedB = B % 8; -- x % 8 has the same effect as x & 0x7 on numbers <= 0xf
--~ 	local knownTypes = {[0]="player", [3]="NPC", [4]="pet", [5]="vehicle"};
--~ 	print("Your target is a " .. (knownTypes[maskedB] or " unknown entity!"));
	if maskedB == 0 then
		return true
	end
	return false
end

--Return the duration of a spell.
function lib:GetDuration(spellID, srcGUID, dstGUID, dstIsPlayer)
	local dstIsPlayer = dstGUID and GUIDIsPlayer(dstGUID) or false
	local spellStr = ""
	if dstIsPlayer and lib.auraInfoPvP[spellID] then
		--Receiver is a player and the spell has a PvP duration. Return the pvp duration.
		local duration = lib.auraInfoPvP[spellID]
		
		if dstGUID and duration then
			--Check if there's dimminshing returns on the spell.
			duration = self:GetDRDuration(dstGUID, spellID, duration)
		end
				
		return tonumber(duration or 0)
	elseif self.auraInfo[spellID] then
		--Check caster GUID was given.
		if srcGUID then
			--Check if we've seen that caster cast a spell with a duration that doesn't match our own (spec/glphed into something?)
			if self.GUIDDurations[srcGUID.."-"..spellID] then
				local dur = self.GUIDDurations[srcGUID.."-"..spellID]
				
				--Check if receiver GUID was given.
				if dstGUID then
					--Check if there's dimminshing returns on the spell.
					dur = self:GetDRDuration(dstGUID, spellID, dur)
				end
				return dur
			end
		end
	
		local duration, debuffType = strsplit(";", self.auraInfo[spellID])
		return tonumber(duration or 0)
	end
end

--Return the debuff type of a spell.
function lib:GetDebuffType(spellID)
	if self.auraInfo[spellID] then
		local duration, debuffType = strsplit(";", self.auraInfo[spellID])
		if debuffType then
			if debuffType == 0 then
				return "None"
			else
				return self.debuffTypes[debuffType] or "unknown"
			end
		end
		return "None"
	end
	return nil
end

function lib:GetNumGUIDAuras(GUID)
	if self.GUIDAuras[GUID] then
		return #self.GUIDAuras[GUID]
	end
	return 0
end

function lib:GetGUIDAuras(GUID)
	if self.GUIDAuras[GUID] then
		return unpack(self.GUIDAuras[GUID])
	end
	return nil
end
--~ name, rank, icon, count,  dispelType, duration, expires, caster,  isStealable, shouldConsolidate, spellID  = UnitAura("unit", index [,  "filter"]) or UnitAura("unit", i)
function lib:GUIDAura(dstGUID, spellID)
	local key = dstGUID.."-"..spellID
	local count = self.GUIDAuraData_stackCount[key] or 1
	local debuffType = self.GUIDAuraData_debuffType[key] or "none"
	local duration = self.GUIDAuraData_duration[key] or 0
	local expires = self.GUIDAuraData_expirationTime[key] or 0
	local isDebuff = lib.GUIDAuraData_isDebuff[key]
	
	return count, debuffType, duration, expires, isDebuff
end

function lib:HasDREffect(dstGUID, spellID)
	local drType = self.drSpells[spellID]
	if drType then
		local key = dstGUID..drType
		local reset = self.GUIDDrEffects_reset[key]
		if reset and GetTime() < reset then
			return true, (self.GUIDDrEffects_diminished[key] or 1)
		end
	end
	return false
end





--[[
function lib:TestGUID(guid)
--~ 	local guid = UnitGUID("target");
	local B = tonumber(guid:sub(5,5), 16);
	local maskedB = B % 8; -- x % 8 has the same effect as x & 0x7 on numbers <= 0xf
	local knownTypes = {[0]="player", [3]="NPC", [4]="pet", [5]="vehicle"};
--~ 	print("Your target is a " .. (knownTypes[maskedB] or " unknown entity!"));
	print("TestGUID", maskedB, (knownTypes[maskedB] or " unknown entity!"))

end

function LAI_Test()--	/run LAI_Test()
	local guid = UnitGUID("target");
	lib:TestGUID(guid)
end]]